# -*- coding:utf-8 -*-
# CREATED BY: bohuai jiang 
# CREATED ON: 2020/8/13 3:55 PM
# LAST MODIFIED ON:
# AIM:
from automata import condition, operation
from automata.state_machine import StateMachine
import attrdict
import matplotlib.pyplot as plt
import time
from automata.sequence import StrSequence



options = {
        'language': 'zh',  # 'zh'中文 'en' 英文
        'long_short_sent_handle': 'y',  # 'y'自然切分，不处理长短句；'n'处理长短句
        'max_length': 5,  # 最长句子，默认值150
        'min_length': 2,  # 最短句子，默认值15
        'hard_max_length': 5,  # 强制截断，默认值300
        'remove_blank': True
    }


Edges = attrdict.AttrDict({
    'is_end_symbol': condition.IsEndSymbolCN(),
    'is_bracket_close': condition.IsBracketClose(),
    'is_book_close': condition.IsBookClose(),
    'is_quote_close': condition.IsQuoteClose(),
    'is_end_state': condition.IsEndState(),
    'is_long_sentence': condition.IsLongSentence(max_len=options['max_length']),
    'is_short_sentence': condition.IsShortSentence(min_len=options['min_length'])
})

Nodes = attrdict.AttrDict({
    'do_cut': operation.Normal(),
    'long_handler': operation.LongHandler(hard_max=options['hard_max_length']),
    #'short_handler': operation.ShortHandler(),
    'init': operation.Indolent(),
    'end': operation.EndState()
})

logic_simple = {
    Nodes.init: [
        {'edge': Edges.is_end_state,
         'node': Nodes.end},

        {'edge': [
                  Edges.is_end_symbol,
                  Edges.is_book_close,
                  Edges.is_bracket_close,
                  Edges.is_quote_close
            ],
         'args': all,
         'node': Nodes.do_cut},

        {'edge': None,
         'node': Nodes.do_cut},
    ],
    Nodes.do_cut: [
        {'edge': Edges.is_end_state,
         'node': Nodes.end},

        {'edge': None,  # else 状态
         'node': Nodes.init},
    ],
}

logic_graph = {
    Nodes.init: [
        {'edge': Edges.is_end_state,
         'node': Nodes.end},

        {'edge': Edges.is_short_sentence,
         'node': Nodes.init},

        {'edge': Edges.is_long_sentence,
         'node': Nodes.long_handler},


        {'edge': [Edges.is_end_symbol,
                  Edges.is_bracket_close,
                  Edges.is_book_close,
                  Edges.is_quote_close],
         'args': all,
         'node': Nodes.do_cut},



    ],
    Nodes.do_cut: [
        {'edge': Edges.is_end_state,
         'node': Nodes.end},

        {'edge': None,  # else 状态
         'node': Nodes.init},
    ],
    Nodes.long_handler: [
        {'edge': Edges.is_end_state,
         'node': Nodes.end},

        {'edge': None,  # else 状态
         'node': Nodes.do_cut},
    ]
}


def check(options, sentence_list) -> bool:
    for sentence in sentence_list:
        if not ( len(sentence) <= options['max_length']):
            print(sentence)
            return False
    else:
        return True


def run_single(sample_size=1):
    sentence = '(太阳当空照.).(花儿对我笑)，"小鸟说早早《哈哈哈！》!"，"你为什么背上书包了,".我去上学校,天天不迟到，爱学习爱劳.' * sample_size
    #machine = StateMachineZH(logic_simple)
    machine = StateMachine(logic_graph)
    start_t = time.time()
    state = StrSequence(sentence, False)
    machine.run(state,verbose=False)
    end_t = time.time() - start_t
    return end_t, state.sentence_list


def test(options):
    time = []
    size = []
    for i in range(1000, 1000000, 1000):
        t, out = run_single(i)
        # if not check(options, sentence_list=out):
        #     raise Exception('分句错误')
        time.append(t)
        size.append(i)
        if i % 100 == 0:
            print(i)
            plt.figure()
            plt.plot(time)
            plt.savefig('perform')
            plt.close()
    #print('\n'.join(out))


if __name__ == '__main__':

     test(options)
    # run_single()



# -*- coding:utf-8 -*-
# CREATED BY: bohuai jiang 
# CREATED ON: 2020/8/7 3:50 PM
# LAST MODIFIED ON: 2021/3/1 3:46 PM
# AIM:
from abc import ABC
from typing import List
import re

from .abc import Criteria
from .sequence import StrSequence, EnSequence
from .symbols import SYMBOLS, SYMBOLS_EN


class IsEndState(Criteria):
    def __init__(self, symbols: dict):
        super(IsEndState, self).__init__('IsEndState', symbols)

    def accept(self, state: StrSequence) -> bool:
        return state.reach_right_end()


class IsEndSymbolCN(Criteria):
    def __init__(self, symbols: dict):
        super(IsEndSymbolCN, self).__init__('IsEndSymbolZH', symbols)
        self.empty = re.compile('\s')

    def is_zh(self, char: str):
        if '\u4e00' <= char <= '\u9fa5':
            return True

    def accept(self, state: StrSequence) -> bool:
        if self.symbols['end_symbols'].match(state.current_value) and \
                not (self.symbols['en_dot'].match(state.next_value) or self.symbols['end_symbols'].match(
                    state.next_value)):
            return True
        if self.symbols['en_dot'].match(state.current_value):
            if self.is_zh(state.next_value) or self.empty.match(state.next_value):
                return True
        return False


class IsEndSymbolEN(Criteria):
    def __init__(self, symbols: dict):
        super(IsEndSymbolEN, self).__init__('IsEndSymbolEN', symbols)
        self.empty = re.compile('\s')
        self.number = re.compile('[0-9]')

    def accept(self, state: StrSequence) -> bool:
        if self.symbols['end_symbols'].match(state.current_value) and \
                not (self.symbols['en_dot'].match(state.next_value) or self.symbols['end_symbols'].match(
                    state.next_value)):
            return True
        if self.symbols['en_dot'].match(state.current_value):

            if self.number.match(state.next_value):
                return False
            else:
                return True
        return False


class IsComma(Criteria):
    def __init__(self, symbols: dict):
        super(IsComma, self).__init__('IsComma', symbols)

    def accept(self, state: StrSequence) -> bool:
        if self.symbols['comma'].match(state.current_value):
            return True
        return False


class IsBracketClose(Criteria):
    def __init__(self, symbols: dict):
        super(IsBracketClose, self).__init__('IsBracketClose', symbols)

    def accept(self, state: StrSequence) -> bool:
        # -- avoid endless loop -- #
        if state.reach_right_end():
            return True
        if state.bracket_left <= state.bracket_right:
            state.reset_bracket()
            return True
        else:
            return False


class IsQuoteClose(Criteria):
    def __init__(self, symbols: dict):
        super(IsQuoteClose, self).__init__('IsQuoteClose', symbols)

    def accept(self, state: StrSequence) -> bool:
        # -- avoid endless loop -- #
        if state.reach_right_end():
            return True

        if state.quota_en > 0:
            if (state.quota_en + state.quota_left) % 2 == 0:
                state.reset_quota()
                return True
            else:
                return False
        elif state.quota_left > 0:
            return False
        else:
            return True


class IsSingleQuoteCloseEn(Criteria):
    def __init__(self):
        super(IsSingleQuoteCloseEn, self).__init__('IsSingleQuoteCloseEn', SYMBOLS_EN)

    def accept(self, state: EnSequence) -> bool:
        # -- avoid endless loop -- #
        if state.reach_right_end():
            return True

        if state.s_quota_en > 0:
            if (state.s_quota_en + state.s_quota_left) % 2 == 0:
                state.reset_s_quota()
                return True
            else:
                return False
        elif state.s_quota_left > 0:
            return False
        else:
            return True


class IsBookClose(Criteria):
    def __init__(self, symbols: dict):
        super(IsBookClose, self).__init__('IsBookClose', symbols)

    def accept(self, state: StrSequence) -> bool:
        # -- avoid endless loop -- #
        if state.reach_right_end():
            return True
        if state.book_left <= state.book_right:
            # state.reset_bookmark()
            return True
        else:
            return False


class IsLongSentence(Criteria):
    def __init__(self, symbols: dict, max_len: int = 128):
        super(IsLongSentence, self).__init__('IsLongSentence', symbols)
        self.max_len = max_len

    def accept(self, state: StrSequence) -> bool:
        if state.candidate_len > self.max_len:
            return True
        return False


class IsShortSentence(Criteria):
    def __init__(self, symbols: dict, min_len: int = 17, **kwargs):
        super(IsShortSentence, self).__init__('IsShortSentence', symbols, **kwargs)
        self.min_len = min_len

    def accept(self, state: StrSequence) -> bool:
        if state.candidate_len < self.min_len:
            return True
        return False


class IsSQuota(Criteria):
    def __init__(self, value: str):
        super(IsSQuota, self).__init__('Criteria', SYMBOLS_EN)
        self.value = value
        assert self.value in ['en', 'left', 'right']
        if self.value == 'left':
            self.pattern = self.symbols['s_quota_left']
        elif self.value == 'right':
            self.pattern = self.symbols['s_quota_right']
        else:
            self.pattern = self.symbols['s_quota_en']
        self.is_blank = re.compile('^\s+')

    def accept(self, state: StrSequence) -> bool:
        if self.pattern.match(state.current_value):
            if state.v_pointer == 0:
                return True
            elif state.v_pointer == state.length - 1:
                return True
            elif self.is_blank.match(state.pre_value) or self.is_blank.match(state.next_value):
                return True
            else:
                return False
        return False


# --- space --- #

class IsSpace(Criteria):
    def __init__(self, symbols: dict):
        super(IsSpace, self).__init__('IsSpace', symbols)
        self.pattern = re.compile('\s')

    def accept(self, state: StrSequence) -> bool:
        if self.pattern.match(state.current_value):
            return True
        else:
            return False


class IsNestSpace(Criteria):
    def __init__(self, symbols: dict):
        super(IsNestSpace, self).__init__('IsNestSpace', symbols)
        self.pattern = re.compile('\s')

    def accept(self, state: StrSequence) -> bool:
        if self.pattern.match(state.next_value):
            return True
        else:
            return False


class IsNextWithSpace(Criteria):
    def __init__(self, symbols: dict):
        super(IsNextWithSpace, self).__init__('IsNextWithSpace', symbols)
        self.pattern = re.compile('\s')

    def accept(self, state: StrSequence) -> bool:
        if self.pattern.match(state.next_value):
            return True
        return False


class IsNextWithEndQuota(Criteria):
    def __init__(self, symbols: dict):
        super(IsNextWithEndQuota, self).__init__('IsNextWithQuota', symbols)

    def accept(self, state: StrSequence) -> bool:
        if self.symbols['quotation_right'].match(state.next_value):
            return True
        elif self.symbols['quotation_en'].match(state.next_value):  # and (state.quota_en + state.quota_left)%2 != 0
            return True
        return False


# =========================== #
#      Special Condition      #
# =========================== #

class SpecialCondition(Criteria, ABC):
    pass


class IsRightQuotaZH(SpecialCondition):
    def __init__(self, index=0):
        super(IsRightQuotaZH, self).__init__('IsRightQuota', SYMBOLS)
        self.index = index

    def accept(self, state: StrSequence) -> bool:
        if self.index >= 0:
            index = min(state.v_pointer + self.index, state.length - 1)
        else:
            index = max(0, state.v_pointer + self.index)
        if self.symbols["quotation_right"].match(state[index]):
            state.reset_quota()
            return True
        return False


class IsLeftQuotaZH(SpecialCondition):
    def __init__(self, index=0):
        super(IsLeftQuotaZH, self).__init__('IsLeftQuotaZH', SYMBOLS)
        self.index = index

    def accept(self, state: StrSequence) -> bool:
        if self.index >= 0:
            index = min(state.v_pointer + self.index, state.length - 1)
        else:
            index = max(0, state.v_pointer + self.index)
        if SYMBOLS["quotation_left"].match(state[index]):
            return True
        return False


class IsLeftQuotaEn(SpecialCondition):
    def __init__(self):
        super(IsLeftQuotaEn, self).__init__('IsListQuota', SYMBOLS_EN)
        self.blank = re.compile('\s')

    def accept(self, state: StrSequence) -> bool:
        if self.symbols['quotation_en'].match(state.current_value) and state.quota_en % 2 != 0 or self.symbols[
            'quotation_left'].match(state.current_value):
            # state.v_pointer = max(0, state.v_pointer - 1)
            return True

        # if self.symbols['quotation_en'].match(state.current_value) and (not self.blank.match(state.next_value)) or \
        #         self.symbols[
        #             'quotation_left'].match(state.current_value):
        #     # state.v_pointer = max(0, state.v_pointer - 1)
        #     return True
        return False


class IsLeftSingleQuotaEn(SpecialCondition):
    def __init__(self):
        super(IsLeftSingleQuotaEn, self).__init__('IsLeftSingleQuotaEn', SYMBOLS_EN)
        self.blank = re.compile('\s')

    def accept(self, state: EnSequence) -> bool:
        if self.symbols['s_quota_en'].match(state.current_value) and state.s_quota_en % 2 != 0 or self.symbols[
            's_quota_left'].match(state.current_value):
            # state.v_pointer = max(0, state.v_pointer - 1)
            return True

        return False


class IsRightQuotaEn(SpecialCondition):
    def __init__(self):
        super(IsRightQuotaEn, self).__init__('SpecialCondition', SYMBOLS_EN)
        self.blank = re.compile('\s')

    def accept(self, state: StrSequence) -> bool:
        if self.symbols['quotation_en'].match(state.current_value) and state.quota_en % 2 == 0 or self.symbols[
            'quotation_right'].match(state.current_value):
            return True

        # if self.symbols['quotation_en'].match(state.current_value) and (
        #         not self.blank.match(state.pre_value)) and state.v_pointer > 0 or \
        #         self.symbols['quotation_right'].match(state.current_value):
        #     # state.v_pointer = max(0, state.v_pointer - 1)
        #     return True
        return False


class IsRightSingleQuotaEn(SpecialCondition):
    def __init__(self):
        super(IsRightSingleQuotaEn, self).__init__('IsRightSingleQuotaEn', SYMBOLS_EN)
        self.blank = re.compile('\s')

    def accept(self, state: EnSequence) -> bool:
        if self.symbols['s_quota_en'].match(state.current_value) and state.s_quota_en % 2 == 0 or self.symbols[
            's_quota_right'].match(state.current_value):
            return True

        return False


class DialogueIsGreaterThanEN(SpecialCondition, ABC):
    def __init__(self, length: int):
        super(DialogueIsGreaterThanEN, self).__init__('DialogueIsGreaterThanEN', SYMBOLS_EN)
        self.length = length
        self.word_pattern = re.compile('^[a-zA-Z0-9]+')

    def accept(self, state: EnSequence) -> bool:
        if state.v_pointer < self.length:
            return False
        i = state.v_pointer
        n_quota = 0
        n_s_quota = 0
        n_word = 0
        s_quota_result = True
        quota_result = True
        while i >= 0:
            if self.symbols['all_quota'].match(state[i]):
                n_quota += 1
            if self.symbols['all_s_quota'].match(state[i]):
                n_s_quota += 1
            if n_quota >= 2:
                quota_result = False
            if n_s_quota >= 2:
                s_quota_result = False
            if self.word_pattern.match(state[i]):
                n_word += 1
                if n_word >= self.length:
                    break
            i -= 1
        if n_quota == 0 and n_s_quota != 0:
            return s_quota_result
        elif n_quota != 0 and n_s_quota == 0:
            return quota_result
        else:
            return s_quota_result or quota_result


class BracketIsGreaterThan(SpecialCondition):
    def __init__(self, length: int, symbols: dict):
        super(BracketIsGreaterThan, self).__init__('BracketIsGreaterThan', symbols)
        self.length = length
        self.word_pattern = re.compile('^[a-zA-Z0-9]+')

    def accept(self, state: StrSequence) -> bool:
        if state.v_pointer < self.length:
            return False
        i = state.v_pointer
        out = True
        n_word = 0
        while i >= 0:
            if self.symbols["bracket_left"].match(state[i]):
                out = False
            if self.word_pattern.match(state[i]):
                n_word += 1
                if n_word > self.length:
                    break
            i -= 1
        return out


class IsLeftQuotaGreaterThan(SpecialCondition):
    '''
    左引号 重复次数大于一定值
    '''

    def __init__(self, theta: int = 1):
        super(IsLeftQuotaGreaterThan, self).__init__('IsLeftQuotaGreaterThan', SYMBOLS)
        self.theta = theta

    def accept(self, state: StrSequence) -> bool:
        if state.quota_left > self.theta:
            state.reset_quota()
            state.v_pointer -= 1
            return True


class IsRQuotaStickWithLQuota(SpecialCondition):
    '''
    右引号紧跟着左引号
    '''

    def __init__(self):
        super(IsRQuotaStickWithLQuota, self).__init__('IsRQuotaStickWithLQuota', SYMBOLS)

    def accept(self, state: StrSequence) -> bool:
        if self.symbols['quotation_right'].match(state.current_value) and \
                self.symbols['quotation_left'].match(state.next_value):
            return True
        return False


class WithSays(SpecialCondition):
    def __init__(self):
        super(WithSays, self).__init__('WithSays', SYMBOLS)
        self.pattern = re.compile('([他她](说|说道|笑道|道))+')

    def accept(self, state: StrSequence) -> bool:
        sentence = state[state.v_pointer + 1:15]
        if self.pattern.match(sentence):
            return True
        return False


class SpecialEnds(SpecialCondition):
    def __init__(self):
        super(SpecialEnds, self).__init__('SpecialEnds', SYMBOLS)
        self.pattern_pre = re.compile('([~～])')
        self.pattern_cur = re.compile('\s')

    def accept(self, state: StrSequence) -> bool:
        if self.pattern_pre.match(state.pre_value) and self.pattern_cur.match(state.current_value):
            return True
        else:
            return False


class NotInWhitelistDotEn(SpecialCondition):
    '''
    note: 大小写敏感
    '''

    def __init__(self, white_list: str):
        super(NotInWhitelistDotEn, self).__init__('NotInWhitelistDotEn', SYMBOLS_EN)
        pattern = re.compile('\s')
        self.white_list = [pattern.sub('', v.strip()) for v in white_list.splitlines()]

    def accept(self, state: EnSequence) -> bool:
        if not state.current_value in ['.', '!']:
            return True
        else:
            for word in self.white_list:
                if not word:
                    continue
                word_token = state.tokenize(word)
                dots_pos = self.find_dot(word_token)
                word_len = len(word_token)
                atcual_word = ''.join(state[state.v_pointer - dots_pos:state.v_pointer])
                if dots_pos == word_len and word == atcual_word:
                    return False
                if dots_pos != word_len:
                    # case Mac. book 走搜索
                    while dots_pos > 0:
                        i = 0
                        whole_word = atcual_word + ''.join(
                            state[state.v_pointer:state.v_pointer + i + word_len - dots_pos])
                        if word == whole_word:
                            state.v_pointer = state.v_pointer + i + word_len - dots_pos
                            return False
                        dots_pos = self.find_dot(word_token, dots_pos + 1)
                        atcual_word = ''.join(state[state.v_pointer - dots_pos:state.v_pointer])
            return True

    def find_dot(self, str_list: List[str], start=0):
        for i, v in enumerate(str_list[start::]):
            if v in ['.', '!']:
                return i + start
        return -1


class IsSenetnecDash(SpecialCondition):
    '''
    检查是否是引文短句dash
    '''

    def __init__(self):
        super(IsSenetnecDash, self).__init__('IsSenetnecDash', SYMBOLS_EN)

    def accept(self, state: StrSequence) -> bool:
        if self.symbols['dash'].match(state.current_value):
            return True
        if self.symbols['short_dash'].match(state.current_value) and self.symbols['short_dash'].match(state.pre_value):
            return True
        return False



# -*- coding:utf-8 -*-
# CREATED BY: bohuai jiang 
# CREATED ON: 2020/8/13 4:55 PM
# LAST MODIFIED ON:
# AIM:

import time
import matplotlib.pyplot as plt


def run_single(sample_size):
    a = '(太阳当空照).(花儿对我笑)，"小鸟说早早"，"你为什么背上书包了,".　\
    我去上学校,天天不迟到，爱学习爱劳.' * sample_size
    a = list(a)
    start_t = time.time()
    # while a:
    #   a.pop()
    #a.pop(0)
    for v in a:
        c = 1+1
    end_t = time.time() - start_t
    return end_t, a


def test():
    time = []
    size = []
    for i in range(1000, 1000000, 1000):
        t, out = run_single(i)
        # if not check(options, sentence_list=out):
        #     raise Exception('分句错误')
        time.append(t)
        size.append(i)
        if i % 100 == 0:
            print(i)
            plt.figure()
            plt.plot(time)
            plt.savefig('perform')
            plt.close()


if __name__ == '__main__':
    test()



# -*- coding:utf-8 -*-
# CREATED BY: jiangbohuai
# CREATED ON: 2021/1/27 2:38 PM
# LAST MODIFIED ON:
# AIM:

import pandas

from sentence_spliter.spliter import cut_to_sentences_en

path = '测试250.xlsx'
data = pandas.read_excel(path)

out =[] 
for sentence in data['原始']:
    sub = cut_to_sentences_en(sentence)
    out.append('\n\n'.join(v.strip() for v in sub))

data['策略：平均子句长度惩罚'] = out

data.to_excel('测试250.xlsx')

print('done')


# -*- coding:utf-8 -*-
# CREATED BY: jiangbohuai
# CREATED ON: 2021/4/26 6:28 PM
# LAST MODIFIED ON:
# AIM:
import unittest
from sentence_spliter.spliter import long_machine_en, cut_to_sentences_en
from sentence_spliter.logic_graph_en import long_cuter_en
from sentence_spliter.automata.sequence import EnSequence
from sentence_spliter.automata.state_machine import StateMachine


# from sentence_spliter.logic_graph_en import


class test_file(unittest.TestCase):
    # @unittest.skip('pass')
    def test_white_list(self):
        with open('file.txt', 'r') as f:
            sentence = f.read()
        m_input = EnSequence(sentence)
        StateMachine(long_cuter_en()).run(m_input)
        expected = m_input.sentence_list()

        print('\n'.join(expected))
        print('\n\n\n')
        for i in range(3):
            m_input = EnSequence(sentence)
            StateMachine(long_cuter_en()).run(m_input)
            out = m_input.sentence_list()
            print('\n'.join(out))
            self.assertEqual(expected, out)



# -*- coding:utf-8 -*-
# CREATED BY: jiangbohuai
# CREATED ON: 2021/1/26 4:20 PM
# LAST MODIFIED ON:
# AIM:
import os
import time
import sys
import re

from sentence_spliter.spliter import cut_to_sentences_en


def print_percent(current: int, max: int, header: str = ''):
    percent = float(current) / max * 100
    sys.stdout.write("\r{0}{1:.3g}%".format(header, percent))
    # sys.stdout.flush()


def print_time_cost(time_start: float, id: int, data_length: int, header: str = ''):
    time_lapse = time.time() - time_start
    average_lapse = time_lapse / float((id + 1))
    time_remain = average_lapse * (data_length - (id + 1))
    print_percent(id, data_length,
                  header='{0} total_datasize {1} [{2}|{3}]， avg_time_pre_batch {4:0.4f}s, time_remain {5}s - '.format(
                      header,
                      data_length,
                      id,
                      data_length,
                      average_lapse,
                      time.strftime("%H:%M:%S", time.gmtime(time_remain)))
                  )


novel_path = '/Users/Shared/cachi/sentence-spliter/测试小说/Bernard-Cornwell---The-Fort,-A-Novel-of-the-Revolutionary-War.txt'

with open(novel_path, 'r') as f:
    data = f.read().replace('\n', '')

data_length = len(data)

start_time = time.time()

out = cut_to_sentences_en(data)
#print_time_cost(start_time, i, data_length)
with open('split_sentences_result.txt', 'a') as f:
    f.write('\n\n'.join(v.strip() for v in out))



data = '''
abbr.
A.D.
adj.
adv.
A.H.
a.m.
A.M.
anon.
arr.
Assoc.
Asst.
attn.
Av.
Ave.
b.
B.A.
B.C.
B.C.E.
B.Ed.
B.Litt
Blvd.
B.Mus
B.Phil
Br.
Brig.
Bros.
B.S.
c.
C.
Capt.
Cdr.
C.E.
cent.
cert.
cf.
chap.
C.-in-C.
Co.
col.
Col.
Con.
conj.
cont.
Corp.
cp.
Cpl.
ct.
Ct.
cu.
d.
D.
D.A.
d.b.a.
deg.
Dem.
dep.
Dept.
det.
Div.
D.Litt
do.
D.O.B.
doz.
Dr.
D.T.'s
ed.
e.g.
enc.
encl.
eng.
esp.
Esq.
etc.
exclam.
ext.
f.
ff.
fig.
f.o.b.
Fr.
ft.
Ft.
gal.
Gen.
gm.
govt.
Gt.
H.E.
H.M.
Hon.
h.p.
hr.
I.
ib.
ibid.
i.e.
in.
inc.
Inc.
incl.
Ind.
Is.
Jr.
l.
L.A.
Lab.
lat.
lb.
l.c.
l.h.
Lieut.
LL.B
LL.D
LL.M
long.
Lt.
m.
M.A.
Maj.
max.
med.
Messrs.
Mgr.
min.
M.O.
Mr.
Mrs.
M.S.
Ms.
Mt.
n.
N.B.
neg.
No.
N.Z.
o.b.o.
o.n.o.
Op.
p.
p.a.
par.
para.
p.d.q.
P.E.
Ph.D.
pl.
Pl.
p.m.
P.M.
pop.
p.p.
prep.
Prof.
pron.
p.s.i.
pt.
p.w.
Q.E.D.
q.v.
R.
Rd.
ref.
Rep.
Rev.
r.h.
R.I.P.
R.S.V.P.
sec.
Sec.
Secy.
Sen.
Sgt.
sing.
So.
Soc.
sq.
Sq.
Sr.
st.
St.
Supt.
symb.
tel.
temp.
T.M.
u.c.
U.K.
U.N.
Univ.
U.S.
U.S.A.
viz.
vol.
yr.
G.L.O.W.
U!S!A!
Washingto, D.C.
Jan.
Feb.
Mar.
Apr.
Jun.
Jul.
Aug.
Sept.
Sep.
Oct.
Nov.
Dec.
Mon.
Tues.
Wed.
Thur.
Fri.
Sat.
Sun.
mm.
dd.
Co.,
Ltd.,
S.
N. 
S.E.
H.K.
N.Y.
lng.
D.C.
'''



# -*- coding:utf-8 -*-
# CREATED BY: jiangbohuai
# CREATED ON: 2021/1/27 3:20 PM
# LAST MODIFIED ON:
# AIM:
import os
from typing import List

from sentence_spliter.automata.symbols import SYMBOLS_EN


def tokenize(sentence:str):
    return SYMBOLS_EN['all_symbols'].split(sentence)

def check_comma(sentence_list: List[str]):
    for sentence in sentence_list:
        count = 0
        for v in tokenize(sentence):
            if SYMBOLS_EN['all_quota'].match(v):
                count += 1



def test_whole_novel(novel_dir: str):
    for file in os.listdir(novel_dir):
        name, extends = os.path.splitext(file)
        if extends == '.txt':
            file_path = os.path.join(novel_dir, file)
            pass


# -*- coding:utf-8 -*-
# CREATED BY: bohuai jiang 
# CREATED ON: 2020/8/19 11:22 AM
# LAST MODIFIED ON:
# AIM:

from sentence_spliter.logic_graph import long_short_cuter, simple_cuter, special_cuter
from sentence_spliter.automata.state_machine import StateMachine
from sentence_spliter.automata.sequence import StrSequence



# -*- coding:utf-8 -*-
# CREATED BY: jiangbohuai
# CREATED ON: 2021/1/21 4:20 PM
# LAST MODIFIED ON:
# AIM:

import unittest
from sentence_spliter.spliter import cut_to_sentences_en
from sentence_spliter.logic_graph_en import long_cuter_en
from sentence_spliter.automata.sequence import EnSequence
from sentence_spliter.automata.state_machine import StateMachine


class test_spliter(unittest.TestCase):
    # @unittest.skip('pass')
    def test_white_list(self):
        sentence = "He was a private in the U.S. Army."
        out = cut_to_sentences_en(sentence)
        expected = ["He was a private in the U.S. Army."]
        self.assertEqual(expected, out)

        sentence = "He was a private in the U.S. Army. AHAH!"
        out = cut_to_sentences_en(sentence)
        expected = ['He was a private in the U.S. Army.', ' AHAH!']
        self.assertEqual(expected, out)

        sentence = "Notice that U.S.A. can also be written USA, but U.S. is better with the periods. Also, we can use U.S. as a modifier (the U.S. policy on immigration) but not as a noun (He left the U.S. U.S.A.)."
        out = cut_to_sentences_en(sentence)
        expected = ['Notice that U.S.A. can also be written USA, but U.S. is better with the '
                    'periods.',
                    ' Also, we can use U.S. as a modifier (the U.S. policy on immigration) ',
                    'but not as a noun (He left the U.S. U.S.A.).']
        self.assertEqual(expected, out)

        sentence = "U.S.A is the ency of the world"
        out = cut_to_sentences_en(sentence)
        expected = ['U.S.A is the ency of the world']
        self.assertEqual(expected, out)
        sentence = "Notice that U.S.A. can also be written USA."
        out = cut_to_sentences_en(sentence)
        expected = ["Notice that U.S.A. can also be written USA."]
        self.assertEqual(expected, out)

        sentence = "Notice that U.S.A. can also be written USA, but U.S. is better with the periods. Also, we can use U.S. as a modifier (the U.S. policy on immigration) but not as a noun (He left the U.S. U.S.A.)."
        out = cut_to_sentences_en(sentence)
        expected = ['Notice that U.S.A. can also be written USA, but U.S. is better with the '
                    'periods.',
                    ' Also, we can use U.S. as a modifier (the U.S. policy on immigration) ',
                    'but not as a noun (He left the U.S. U.S.A.).']
        self.assertEqual(expected, out)

        sentence = "Mrs. Gibson, meanwhile, counting her stitches aloud with great distinctness and vigour."
        out = cut_to_sentences_en(sentence)
        expected = ["Mrs. Gibson, meanwhile, counting her stitches aloud with great distinctness and vigour."]
        self.assertEqual(expected, out)

        sentence = "Dr. Who and Who Dr. aren't same person."
        out = cut_to_sentences_en(sentence)
        expected = ["Dr. Who and Who Dr. aren't same person."]
        self.assertEqual(expected, out)

        # sentence = ""

    # @unittest.skip('pass')
    def test_bracket_quota(self):
        sentence = ' "keep forawrd !!", said he. (but he already tired..)'
        out = cut_to_sentences_en(sentence)
        expected = [' "keep forawrd !!", said he. (but he already tired..)']
        self.assertEqual(expected, out)

        sentence = '“Which, if true, will have been recorded in the muster returns. Does it require a general to inspect the books? A clerk could do that.”'
        out = cut_to_sentences_en(sentence)
        expected = [
            '“Which, if true, will have been recorded in the muster returns. Does it require a general to inspect the books? A clerk could do that.”']
        self.assertEqual(expected, out)

    # @unittest.skip('pass')
    def test_dialogue(self):
        sentence = '"you are all lying !" "I am won!!!","Joe, you know I won!!!"'
        out = cut_to_sentences_en(sentence)
        expected = ['"you are all lying !" "I am won!!!","Joe, you know I won!!!"']
        self.assertEqual(expected, out)

        sentence = '"you are all lying !""I am won!!!","Joe, you know I won!!!"'
        out = cut_to_sentences_en(sentence)
        expected = ['"you are all lying !""I am won!!!","Joe, you know I won!!!"']
        self.assertEqual(expected, out)

        sentence = '"you are all lying lying lying and lying!"     "I am won!!!","Joe, you know I won!!!"'
        out = cut_to_sentences_en(sentence)
        expected = ['"you are all lying lying lying and lying!"     ', '"I am won!!!","Joe, you know I won!!!"']
        self.assertEqual(expected, out)

        sentence = '"you are all lying lying lying and lying!""I am won!!!","Joe, you know I won!!!"'
        out = cut_to_sentences_en(sentence)
        expected = ['"you are all lying lying lying and lying!"', '"I am won!!!","Joe, you know I won!!!"']
        self.assertEqual(expected, out)

        sentence = '“This presupposes that you have disposed of the enemy’s shore battery?” “It does, sir.” “A joint attack, eh?”'
        out = cut_to_sentences_en(sentence)
        expected = ['“This presupposes that you have disposed of the enemy’s shore battery?” ',
                    '“It does, sir.” “A joint attack, eh?”']
        self.assertEqual(expected, out)

    # @unittest.skip('pass')
    def test_short_stence(self):
        sentence = '1. 2 3 4. 1 2 3 4 5 6. 1 2 3 4 5 6 7 8.'
        out = cut_to_sentences_en(sentence)
        expected = ['1. 2 3 4. 1 2 3 4 5 6.', ' 1 2 3 4 5 6 7 8.']
        self.assertEqual(expected, out)

    # @unittest.skip('pass')
    def test_long_cutter(self):
        # __long_machine_en = StateMachine(long_cuter_en(max_len=9))
        #
        # sentence = '"1 2 3 4 5 6 7?" cried Henry'
        # m_input = EnSequence(sentence)
        # __long_machine_en.run(m_input)
        # out = m_input.sentence_list()
        # m_input.sentence_list()
        # expected = ['"1 2 3 4 5 6 7?"', ' cried Henry']
        # self.assertEqual(expected, out)
        #
        # sentence = '1 3 5 6 7 8 9 10, where 1 2 3 4.'
        # m_input = EnSequence(sentence)
        # __long_machine_en.run(m_input)
        # out = m_input.sentence_list()
        # m_input.sentence_list()
        # expected = ['1 3 5 6 7 8 9 10, ', 'where 1 2 3 4.']
        # self.assertEqual(expected, out)

        sentence = "\"What would a stranger do here, Mrs. Price?\" he inquired angrily, remembering, with a pang, that certain new, unaccountable, engrossing emotions had quite banished Fiddy from his thoughts and notice, when he might have detected the signs of approaching illness, met them and vanquished them before their climax."
        __long_machine_en = StateMachine(long_cuter_en(max_len=9, min_len=3))
        m_input = EnSequence(sentence)
        __long_machine_en.run(m_input)
        for v in m_input.sentence_list():
            print(v)

    # @unittest.skip('pass')
    def test_sample2(self):
        # sentence = '. . . . We now commend you to the Supream being Sincerely praying him to preserve you and the Forces under your Command in health and safety, & Return you Crowned with Victory and Laurels.'
        #
        # out = cut_to_sentences_en(sentence)
        # for v in out:
        #     print(v + "\n")

        sentence = '978-0-06-196963-8 EPub Edition © 2010 ISBN: 9780062013842 10 11 12 13 14 OFF/RRD 10 9 8 7 6 5 4 3 2 1 About the Publisher Australia HarperCollins Publishers (Australia) Pty. Ltd. 25 Ryde Road (PO Box 321) Pymble, NSW 2073, Australia http://www.harpercollinsebooks.com.au Canada HarperCollins Canada 2 Bloor Street East - 20th Floor Toronto, ON, M4W, 1A8, Canada http://www.harpercollinsebooks.ca New Zealand HarperCollinsPublishers (New Zealand) Limited P.O. Box 1 Auckland, New Zealand'

        __long_machine_en = StateMachine(long_cuter_en(max_len=9))
        m_input = EnSequence(sentence)
        out = __long_machine_en.run(m_input)
        for v in out:
            print(v + "\n")

    # @unittest.skip('pass')
    def test_demo(self):
        # paragraph = "A long time ago. there is a mountain, and there is a temple in the mountain!!! And here is an old monk in the temple!?...."
        # __long_machine_en = StateMachine(long_cuter_en(min_len=4))
        # m_input = EnSequence(paragraph)
        # __long_machine_en.run(m_input)
        # print(m_input.sentence_list())

        paragraph = "A long time ago. There is a mountain, and there is a temple in the mountain!!! And here is an old monk in the temple!?...."
        __long_machine_en = StateMachine(long_cuter_en(max_len=11, min_len=3))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        print(m_input.sentence_list())

    # @unittest.skip('pass')
    def test_bug_2021_3_19(self):
        paragraph = "\"Er ... \" Da ji covered his head and didn' t know what to do. "
        out = cut_to_sentences_en(paragraph)
        print(out)

    # @unittest.skip('pass')
    def test_bug_2021_3_31(self):
        paragraph = "In the new economy, computer science isn’t an optional skill – it’s a basic skill, right along with the three “Rs.”  Nine out of ten parents want it taught at their children’s schools."
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        expect = ['In the new economy, computer science isn’t an optional skill – it’s a basic '
                  'skill,', ' right along with the three “Rs.”  Nine out of ten parents want it taught at '
                            'their children’s schools.']
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_3_31_break(self):
        paragraph = '"I like big meat meat meat meat meat meat meat meat!"'
        __long_machine_en = StateMachine(long_cuter_en(max_len=2))
        expect = ['"I like big meat meat meat meat meat meat meat meat!"']
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_1_1(self):
        paragraph = '"you know worlds is differenct now." "your need to change your mind."'
        __long_machine_en = StateMachine(long_cuter_en(max_len=2))
        expect = ['"you know worlds is differenct now." ', '"your need to change your mind."']
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        # print(acutal)
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_1_2(self):
        paragraph = '"you know worlds is differenct now.""your need to change your mind."'
        __long_machine_en = StateMachine(long_cuter_en(max_len=5))
        expect = ['"you know worlds is differenct now."', '"your need to change your mind."']
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_1_3(self):
        paragraph = 'In a world of uncertainty, we must cherish the importance of “you you you you you me,” “you,” and “us.”'
        __long_machine_en = StateMachine(long_cuter_en(min_len=2, max_len=30))
        expect = ['In a world of uncertainty, we must cherish the importance of “you you you you you me,” ',
                  '“you,” and “us.”']
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        # print(acutal)
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_1(self):
        paragraph = "I found again the people I love. The other members. my family, my friends. I found the music I love, and I found myself. Thinking about the future and trying hard are all important. But cherishing yourself, encouraging yourself and keeping yourself happy is the most important. In a world of uncertainty, we must cherish the importance of “me,” “you,” and “us.”"
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        expect = ['I found again the people I love.',
                  ' The other members. my family, my friends.',
                  ' I found the music I love, and I found myself.',
                  ' Thinking about the future and trying hard are all important.',
                  ' But cherishing yourself, encouraging yourself and keeping yourself happy is the most important.',
                  ' In a world of uncertainty, we must cherish the importance of “me,” “you,” and “us.”']
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print('\n'.join(acutal))
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_2(self):
        paragraph = 'In his own farewell address, George Washington wrote that self-government is the underpinning of our safety, prosperity, and liberty, but “from different causes and from different quarters much pains will be taken… to weaken in your minds the conviction of this truth;” that we should preserve it with “jealous anxiety;” that we should reject “the first dawning of every attempt to alienate any portion of our country from the rest or to enfeeble the sacred ties” that make us one.'
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=25))
        expect = ['In his own farewell address, George Washington wrote that self-government is '
                  'the underpinning of our safety, prosperity,',
                  ' and liberty, but “from different causes and from different quarters much '
                  'pains will be taken…',
                  ' to weaken in your minds the conviction of this truth;” ',
                  'that we should preserve it with “jealous anxiety;” that we should reject '
                  '“the first dawning of every attempt to alienate any portion of our country '
                  'from the rest or to enfeeble the sacred ties” ',
                  'that make us one.']
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        # print(acutal)
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_long_handler_in_quota(self):
        paragraph = '"1" "2 3" 4 5 6 7 8 9 10. 11 12 13 14 15 16 17. "18 19 20 21 22 23 24 25. 26 27 1 1 28 29 30 31 32 33." 34 35 36 37. 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57.'
        __long_machine_en = StateMachine(long_cuter_en(min_len=10, max_len=30))
        expect = ['"1" "2 3" 4 5 6 7 8 9 10.',
                  ' 11 12 13 14 15 16 17. "18 19 20 21 22 23 24 25. 26 27 1 1 28 29 30 31 32 '
                  '33." 34 35 36 37.',
                  ' 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57.']
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_3(self):
        paragraph = "After that, di wuchang and Hong Tao also came, and the four of them were busy for a while. It was not until after nine in the morning that gu pengdong and sha zhan arrived at zhongjin building with the students from fudan university. The sand show coordinated the two buses with fudan university's spray painting. All the people who got off the bus were young men, full of youth and vitality. They had the school badge on their chests. The security guards at the door and the small white-collar workers in the same office building were all dumbfounded. No one had ever seen such a big scene. In a place like shanghai, the brand of fudan university was so loud that it was easy for thieves to make use of it. The two vice presidents were dressed in suits and had elegant demeanors. Such a group of people stood in the lobby waiting for the elevator and immediately attracted everyone's attention. Within a few minutes, the news spread throughout the zhongjin building, causing a huge sensation. Rumor has it that the newly opened star technology on the 16th floor has a mysterious background and has a very special relationship with fudan university. Many business leaders in the same building secretly decided to find an opportunity to visit. How did luo jia know about this? He was busy greeting the two presidents and the top students of fu dan. The zhongjin building is a high-end office building. It is very famous in the Xujiahui area. Its decoration and layout are all first-class. Within the building, there are several branches of the yangtze river delta of the world's top 500 enterprises. The surrounding traffic is convenient and business is developed. It is a typical place where every inch of land is gold. Luo jianeng opened the company here, which was enough to prove her strength. The students of fu dan were very excited to be able to work and study here for a period of time. What made them even more excited was the company's treatment. Just entered the door, each person is a $ 5,000 opening red packet, although it is now the era of mobile payment, luo jia took out cash. It was also money. The money in the phone looked like a cold string of numbers. Cash, on the other hand, was different. It was full of envelopes, thick stacks, and each one of them was a brand new grandpa with big red hair. It was heavy in his pocket, and there was a strong sense of satisfaction. Ren Zhengfei said that if you give enough money, you will become a talent if you are not a talent. Luo jia is not a stingy person in this regard. This is the 21st century, what is the most expensive? Talent! In luo jia's eyes, these students with the school badges on them were little golden men who could walk. Those who wanted to make a lot of money for themselves in the future would not be able to do so unless they were raised fat. The tea room was filled with all kinds of drinks, including red bull, nestle, little ming, and snacks such as chocolate, pistachios, and biscuits. As a traditional item in the internet industry, there were also many instant noodles. At the end of april, watermelons and strawberries were so expensive that luo jia asked the fruit store to bring two large baskets full of them. As a technical manager, li molan was busy introducing luo jia. Not to mention, at least 12 team leaders, luo jia, wanted to meet. Di wuchang and Hong Tao, who had been following luo jia these days, were also one of the team leaders.\" Sure, your company is very good."
        __long_machine_en = StateMachine(long_cuter_en(min_len=10, max_len=20))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        expect = ['After that, di wuchang and Hong Tao also came, and the four of them were '
                  'busy for a while.',
                  ' It was not until after nine in the morning that gu pengdong and sha zhan '
                  'arrived at zhongjin building with the students from fudan university.',
                  " The sand show coordinated the two buses with fudan university's spray "
                  'painting.',
                  ' All the people who got off the bus were young men, full of youth and '
                  'vitality.',
                  ' They had the school badge on their chests. The security guards at the door '
                  'and the small white-collar workers in the same office building were all '
                  'dumbfounded.',
                  ' No one had ever seen such a big scene. In a place like shanghai,',
                  ' the brand of fudan university was so loud that it was easy for thieves to '
                  'make use of it.',
                  ' The two vice presidents were dressed in suits and had elegant demeanors.',
                  ' Such a group of people stood in the lobby waiting for the elevator and '
                  "immediately attracted everyone's attention.",
                  ' Within a few minutes, the news spread throughout the zhongjin building, '
                  'causing a huge sensation.',
                  ' Rumor has it that the newly opened star technology on the 16th floor has a '
                  'mysterious background and has a very special relationship with fudan '
                  'university.',
                  ' Many business leaders in the same building secretly decided to find an '
                  'opportunity to visit.',
                  ' How did luo jia know about this? He was busy greeting the two presidents '
                  'and the top students of fu dan.',
                  ' The zhongjin building is a high-end office building. It is very famous in '
                  'the Xujiahui area.',
                  ' Its decoration and layout are all first-class. Within the building,',
                  " there are several branches of the yangtze river delta of the world's top "
                  '500 enterprises.',
                  ' The surrounding traffic is convenient and business is developed. It is a '
                  'typical place where every inch of land is gold.',
                  ' Luo jianeng opened the company here, which was enough to prove her '
                  'strength.',
                  ' The students of fu dan were very excited to be able to work and study here '
                  'for a period of time.',
                  " What made them even more excited was the company's treatment.",
                  ' Just entered the door, each person is a $ 5,000 opening red packet,',
                  ' although it is now the era of mobile payment, luo jia took out cash.',
                  ' It was also money. The money in the phone looked like a cold string of '
                  'numbers.',
                  ' Cash, on the other hand, was different. It was full of envelopes, thick '
                  'stacks,',
                  ' and each one of them was a brand new grandpa with big red hair.',
                  ' It was heavy in his pocket, and there was a strong sense of satisfaction.',
                  ' Ren Zhengfei said that if you give enough money, you will become a talent '
                  'if you are not a talent.',
                  ' Luo jia is not a stingy person in this regard.',
                  ' This is the 21st century, what is the most expensive?',
                  " Talent! In luo jia's eyes, these students with the school badges on them "
                  'were little golden men who could walk.',
                  ' Those who wanted to make a lot of money for themselves in the future would '
                  'not be able to do so unless they were raised fat.',
                  ' The tea room was filled with all kinds of drinks, including red bull, '
                  'nestle, little ming,',
                  ' and snacks such as chocolate, pistachios, and biscuits. As a traditional '
                  'item in the internet industry,',
                  ' there were also many instant noodles. At the end of april,',
                  ' watermelons and strawberries were so expensive that luo jia asked the fruit '
                  'store to bring two large baskets full of them.',
                  ' As a technical manager, li molan was busy introducing luo jia.',
                  ' Not to mention, at least 12 team leaders, luo jia, wanted to meet.',
                  ' Di wuchang and Hong Tao, who had been following luo jia these days,',
                  ' were also one of the team leaders." Sure, your company is very good.']
        # print(acutal)
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_3_1(self):
        paragraph = "The show's writers gave these tropes a 2021 refresh by leaning into the \"woke\" culture of millennials and Gen Z, calling out intolerance, accepting and normalising LGBTQ+ issues, and highlighting struggles faced by minorities living in the US – African-Americans in particular."
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        expect = ["The show's writers gave these tropes a 2021 refresh by leaning into the "
                  '"woke" culture of millennials and Gen Z,',
                  ' calling out intolerance, accepting and normalising LGBTQ+ issues, and '
                  'highlighting struggles faced by minorities living in the US – '
                  'African-Americans in particular.']  # print(acutal)
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_6(self):
        paragraph = """ "A lot of studies show that (masks)don't help the situation with COVID-19 at all," Altherr said. "And not only political, but spiritual beliefs ... the mask represents compliance and silence, being silenced and not being able to speak your opinions. It represents being controlled by the government. There's a lot of stuff to it that I just don't agree with." """
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        expect = [' "A lot of studies show that (masks)don\'t help the situation with COVID-19 at all," Altherr said.',
                  ' "And not only political, but spiritual beliefs ...',
                  ' the mask represents compliance and silence, being silenced and not being able to speak your opinions.',
                  ' It represents being controlled by the government.',
                  ' There\'s a lot of stuff to it that I just don\'t agree with." ']
        # print(acutal)

        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_6_1(self):
        paragraph = "A very touching 2012 documentary that reunites the original G.L.O.W. wrestlers is available to stream on Netflix. "
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        expect = ['A very touching 2012 documentary that reunites the original G.L.O.W. '
                  'wrestlers is available to stream on Netflix.',
                  ' ']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_6_2(self):
        paragraph = "That's fine: Miracle is one of those rare rah-rah movies that deeply, genuinely earns its U!S!A! U!S!A! spirit, presenting us with a collection of blue-collar kids working together to raise the nation's morale."
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        expect = [
            "That's fine: Miracle is one of those rare rah-rah movies that deeply, genuinely earns its U!S!A! U!S!A! spirit,",
            " presenting us with a collection of blue-collar kids working together to raise the nation's morale."]
        print('\n'.join(acutal))

        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_6_3(self):
        paragraph = "Trump ignited a furor after signing the order to ban U.S. entities from dealing with WeChat -- along with TikTok, ByteDance Ltd.’s viral video platform -- from September. Confusion reigned as investors grappled with the sweeping language of Trump’s order -- which bars “transactions” with the Chinese company -- that leaves the door open for the administration to extend it well beyond the service in America. "
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        expect = ['Trump ignited a furor after signing the order to ban U.S. entities from '
                  'dealing with WeChat -- along with TikTok, ByteDance Ltd.’s viral video '
                  'platform -- from September.',
                  ' Confusion reigned as investors grappled with the sweeping language of '
                  'Trump’s order --',
                  ' which bars “transactions” with the Chinese company -- that leaves the door '
                  'open for the administration to extend it well beyond the service in America.',
                  ' ']

        print(acutal)

        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_6_4(self):
        paragraph = "Some of the best conversations that I have had about history and about the history of slavery have been with 5 - year - olds, 7 - year - olds, 9 - year - olds. It is so important that we know our history, that we teach all aspects of history, even the tough parts, the subjects that make us uncomfortable, the subjects that make us feel ashamed about our nation. That's when we are in a place where we can move forward and grow and live in a realistic space. "
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        expect = ['Some of the best conversations that I have had about history and about the '
                  'history of slavery have been with 5 - year - olds, 7 - year - olds, 9 - year - olds.',
                  ' It is so important that we know our history, that we teach all aspects of history,',
                  ' even the tough parts, the subjects that make us uncomfortable, the subjects that make us feel ashamed about our nation.',
                  " That's when we are in a place where we can move forward and grow and live "
                  'in a realistic space.',
                  ' ']

        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_6_5(self):
        paragraph = """ *On the Internet, @ (pronounced "at" or "at sign" or "address sign") is the symbol in an e-mail address that separates the name of the user from the user's Internet address, as in this hypothetical e-mail address example: msmuffet@tuffet.org.  """
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        expect = [' *On the Internet, @ (pronounced "at" or "at sign" or "address sign") ',
                  'is the symbol in an e-mail address that separates the name of the user from '
                  "the user's Internet address, as in this hypothetical e-mail address example:",
                  ' msmuffet@tuffet.org.  ']
        print('\n'.join(acutal))
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_6_6(self):
        paragraph = """Lee Bo-jin is the second daughter of the chairman of Samsung, the "genuine" heir of Korea's largest chaebol. Ms. Lee is currently running the family's Shilla hotel chain. With everything from money to power, Lee Bo-jin has always been dubbed the "No. 1 Korean woman" and ranked 87th in the top 100 most powerful women in the world voted by Forbes magazine. However, inside that flashy life is a tragic life of the "Samsung princess". *
    *Princess means the richest woman in the country."""
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        expect = ['Lee Bo-jin is the second daughter of the chairman of Samsung, the "genuine" '
                  "heir of Korea's largest chaebol.",
                  " Ms. Lee is currently running the family's Shilla hotel chain.",
                  ' With everything from money to power,',
                  ' Lee Bo-jin has always been dubbed the "No. 1 Korean woman" and ranked 87th '
                  'in the top 100 most powerful women in the world voted by Forbes magazine.',
                  ' However, inside that flashy life is a tragic life of the "Samsung '
                  'princess".',
                  ' *\n    *Princess means the richest woman in the country.']

        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_6_8(self):
        paragraph = """These uses often vary depending upon the language of the text it is used in. The word “tilde” originally came from the Latin word titulus meaning “title” or “superscription,” and made its way to English from Spanish. Like ~ in the sea. """
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        expect = ['These uses often vary depending upon the language of the text it is used in. '
                  'The word “tilde” originally came from the Latin word titulus meaning “title” '
                  'or “superscription,” and made its way to English from Spanish.',
                  ' Like ~ in the sea. ']

        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_6_9(self):
        paragraph = "The night was rapidly approaching; and already, at the cry of “Moccoletti!” repeated by the shrill voices of a thousand vendors, two or three stars began to burn among the crowd. It was a signal. At the end of ten minutes fifty thousand lights glittered, descending from the Palazzo di Venezia to the Piazza del Popolo, and mounting from the Piazza del Popolo to the Palazzo di Venezia. It seemed like the fête of Jack-o’-lanterns."
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        expect = ['The night was rapidly approaching; and already, at the cry of “Moccoletti!” '
                  'repeated by the shrill voices of a thousand vendors,',
                  ' two or three stars began to burn among the crowd.',
                  ' It was a signal. At the end of ten minutes fifty thousand lights glittered, '
                  'descending from the Palazzo di Venezia to the Piazza del Popolo,',
                  ' and mounting from the Piazza del Popolo to the Palazzo di Venezia.',
                  ' It seemed like the fête of Jack-o’-lanterns.']

        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_10(self):
        paragraph = "Some of the fellows pretended to think I was mad when I rushed at Chandos and hugged him, and shouted, \"It's all your doing, old fellow. I'm going to sea! I'm going to sea!\""
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = [
            'Some of the fellows pretended to think I was mad when I rushed at Chandos and hugged him, and shouted, "It\'s all your doing, old fellow.',
            ' I\'m going to sea! I\'m going to sea!"']

        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_10_1(self):
        paragraph = "And today, I signed into law the American Rescue Plan, an historic piece of legislation that delivers immediate relief to millions of people. It includes $1,400 in direct rescue checks — payments. "
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ['And today, I signed into law the American Rescue Plan, an historic piece of '
                  'legislation that delivers immediate relief to millions of people.',
                  ' It includes $1,400 in direct rescue checks — payments.',
                  ' ']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_10_2(self):
        paragraph = "But Nicholson added a little something to cut the tension — the production went through dozens of doors before director Stanley Kubrick was satisfied — and his improvised \"Here's Johnny!\" made the cut."
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ['But Nicholson added a little something to cut the tension —',
                  ' the production went through dozens of doors before director Stanley Kubrick '
                  'was satisfied — and his improvised "Here\'s Johnny!" made the cut.']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_10_3(self):
        paragraph = "Stock up on gifts and shoes from lesser-known designers at pastel-painted boutique TenOverSix and spot celebrities at DASH boutique, a 2,000-square-foot space at 8420 Melrose Avenue owned by the Kardashian sisters. "

        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ['Stock up on gifts and shoes from lesser-known designers at pastel-painted '
                  'boutique TenOverSix and spot celebrities at DASH boutique,',
                  ' a 2,000-square-foot space at 8420 Melrose Avenue owned by the Kardashian '
                  'sisters.',
                  ' ']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_10_4(self):
        paragraph = "'\"Who was it used to pray, O God, make me good, but not yet\"?' and 1 2 3 4 5 6 7"
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ['\'"Who was it used to pray, O God, make me good, but not yet"?\' and 1 2 3 4 5 6 7']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_10_5(self):
        paragraph = "'Charles Irving.'"
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ["'Charles Irving.'"]
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_12(self):
        paragraph = 'I\'m coming to it! All right. I\'m coming to it! I was going to say that when I listened that morning, I listened with admiration amounting to haw. I thought to myself, "Here\'s a man with a wooden leg—a literary man with—"'

        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ["I'm coming to it! All right.",
                  " I'm coming to it! I was going to say that when I listened that morning, I "
                  'listened with admiration amounting to haw.',
                  ' I thought to myself, "Here\'s a man with a wooden leg—a literary man with—"']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_12_1(self):
        paragraph = "'I'm coming to it! All right. I'm coming to it! I was going to say that when I listened that morning, I listened with admiration amounting to haw. I thought to myself, \"Here's a man with a wooden leg—a literary man with—\"'"

        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ["'I'm coming to it! All right.",
                  " I'm coming to it! I was going to say that when I listened that morning, I "
                  'listened with admiration amounting to haw.',
                  ' I thought to myself, "Here\'s a man with a wooden leg—a literary man '
                  'with—"\'']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_15(self):
        paragraph = "'Calls me Sir!' said Mr Wegg, to himself; 'HE won't answer. A bow gone!'"
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ["'Calls me Sir!' said Mr Wegg, to himself;", " 'HE won't answer. A bow gone!'"]
        self.assertEqual(expect, acutal)



# -*- coding:utf-8 -*-
# CREATED BY: jiangbohuai
# CREATED ON: 2021/4/15 4:52 PM
# LAST MODIFIED ON:
# AIM:

import unittest
from sentence_spliter.logic_graph_en import long_cuter_en
from sentence_spliter.automata.sequence import EnSequence
from sentence_spliter.automata.state_machine import StateMachine


class test_spliter(unittest.TestCase):
    # @unittest.skip('pass')
    def test_bug_2021_4_15(self):
        paragraph = "five sisters and a cousin. And when the party entered the assembly room it consisted of only five altogether-Mr. Bigley, his two sisters, the husband of the eldest, and another you man."

        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ['five sisters and a cousin. And when the party entered the assembly room it '
                  'consisted of only five altogether-Mr. Bigley,',
                  ' his two sisters, the husband of the eldest, and another you man.']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_15_1(self):
        paragraph = "While there are many ways of improving time management — such as writing a schedule, prioritizing, adjusting your sleeping patterns, and downloading productivity apps — if you don't fully understand why time management is improtant, you may not have the motivation to change."
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ['While there are many ways of improving time management —',
                  ' such as writing a schedule, prioritizing, adjusting your sleeping patterns, '
                  'and downloading productivity apps —',
                  " if you don't fully understand why time management is improtant, you may not "
                  'have the motivation to change.']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_15_2(self):
        paragraph = "On one occasion, an employee was passed over for a management position because this individual left " \
                    "work every day at exactly 5:00 p.m. - not 5:01 p.m. or 5:02 p.m. Regardless of what was going on or " \
                    "what deadline was looming, the employee refused to stay one minute past 5:00 p.m. However, the other managers " \
                    "at the organization rarely left work on time, and if they did, they would often continue working when they arrived at home."
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ['On one occasion, an employee was passed over for a management position '
                  'because this individual left work every day at exactly 5:00 p.m. - not 5:01 '
                  'p.m. or 5:02 p.m. Regardless of what was going on or what deadline was '
                  'looming,',
                  ' the employee refused to stay one minute past 5:00 p.m. However, the other '
                  'managers at the organization rarely left work on time,',
                  ' and if they did, they would often continue working when they arrived at '
                  'home.']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_15_3(self):
        paragraph = "embattled we are-- but a call to bear the burden of a long twilight struggle, year in and year out,\"rejoicing in hope, " \
                    "patient in tribulation\"--a struggle against the common enemies of man: tyranny, poverty, disease and war itslef."
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ['embattled we are-- but a call to bear the burden of a long twilight '
                  'struggle, year in and year out,"rejoicing in hope, patient in tribulation"--',
                  'a struggle against the common enemies of man: tyranny, poverty, disease and war itslef.']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_15_4(self):
        paragraph = "'\"I thought it too, when I went off watch\"--we was standing six hours on and six off--\"but the boys told me," \
                    " \" I says, \" thata the raft didn't seem to hardly move, for the last hour,\" says I, \"thought she's a slipping along all right, now,\""
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ['\'"I thought it too, when I went off watch"--',
                  'we was standing six hours on and six off--',
                  '"but the boys told me, " I says, " thata the raft didn\'t seem to hardly move, for the last hour," ',
                  'says I, "thought she\'s a slipping along all right, now,"']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_15_5(self):
        paragraph = "Adiminstration in Wshington, D.C. To me the office of the Vice Presidency of the United States is a great office, " \
                    "and I feel that the people have got to have confidence in the integrity if the men who run."
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ['Adiminstration in Wshington, D.C. To me the office of the Vice Presidency of '
                  'the United States is a great office,',
                  ' and I feel that the people have got to have confidence in the integrity if '
                  'the men who run.']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_16(self):
        paragraph = "Job seekers are misusing the Internet by relying too much on its networks and forgetting there is " \
                    "less room for rejection when meeting with someone in person (no unanswered e-mails, for example). " \
                    "\"Go to at least two or three meetups a month, and bring business cards and introduce yourself to " \
                    "random people,\" said Strom. \"Don't be shy, even if you aren't the most outgoing person, " \
                    "talk to one or two strangers at these meetups, and see if you can find common ground.\""
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ['Job seekers are misusing the Internet by relying too much on its networks '
                  'and forgetting there is less room for rejection when meeting with someone in '
                  'person (no unanswered e-mails,',
                  ' for example). "Go to at least two or three meetups a month, and bring '
                  'business cards and introduce yourself to random people," said Strom.',
                  ' "Don\'t be shy, even if you aren\'t the most outgoing person, talk to one '
                  'or two strangers at these meetups, and see if you can find common ground."']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_16_1(self):
        paragraph = "'“O God, 1231231 233123 make me good, but not yet”?' go go go go go go go"
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=10))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ["'“O God, 1231231 233123 make me good, but not yet”?' ",
                  'go go go go go go go']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_16_2(self):
        paragraph = "‘“O God, 1231231 233123 make me good, but not yet”?’ go go go go go go go"
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=10))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ["‘“O God, 1231231 233123 make me good, but not yet”?’ ",
                  'go go go go go go go']
        self.assertEqual(expect, acutal)

    # @unittest.skip('pass')
    def test_bug_2021_4_26(self):
        paragraph = " 'Do you mean to say, child, that any human being has gone into a Christian church, and got herself named Peggotty?' 'It's her surname,' said my mother, faintly."
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = [
            " 'Do you mean to say, child, that any human being has gone into a Christian church, and got herself named Peggotty?' ",
            "'It's her surname,' said my mother, faintly."]
        self.assertEqual(expect, acutal)

    def test_bug_2021_4_29(self):
        paragraph = "(Do you mean to say, child, that any human being has gone into a Christian church, and got herself named Peggotty?) It's her surname, said my mother, faintly."
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=21))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = ['(Do you mean to say, child, that any human being has gone into a Christian '
                  'church, and got herself named Peggotty?) ',
                  "It's her surname, said my mother, faintly."]
        self.assertEqual(expect, acutal)

    def test_bug_2021_4_29_1(self):
        paragraph = " ' Do you mean to say, child, that any human being has gone' into a Christian church, and got herself named Peggotty?"
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=15))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = [" ' Do you mean to say, child, that any human being has gone' ",
                  'into a Christian church, and got herself named Peggotty?']
        self.assertEqual(expect, acutal)

        paragraph = " ' Do you mean to say, child, that any human being has gones' into a Christian church, and got herself named Peggotty?"
        __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=15))
        m_input = EnSequence(paragraph)
        __long_machine_en.run(m_input)
        acutal = m_input.sentence_list()
        print(acutal)
        expect = [" ' Do you mean to say, child,",
                  " that any human being has gones' into a Christian church, and got herself "
                  'named Peggotty?']
        self.assertEqual(expect, acutal)
